==> _private_core_network-0.0.1.tar.gz: lib/network_resources/model/br_place_invite.dart <==
import 'package:_private_core/_private_core.dart';

class BrPlaceInviteModel {
  String? id;
  int? datetimeStartWished;
  int? maxDateTimeAnswer;
  OobrPlaceInfo? oobrPlaceInfo;
  List<InvitedUsers>? invitedUsers;
  String? message;

  bool get isLate =>
      fromTimestamp(datetimeStartWished!).isBefore(DateTime.now()) ||
      fromTimestamp(maxDateTimeAnswer!).isBefore(DateTime.now());

  InvitedUsers get me =>
      invitedUsers!.firstWhere((e) => e.id == appPrefs.loginUser!.type);

  bool get wasAnwserd => me.status != null && me.status! > 0;

  BrPlaceInviteModel(
      {this.id,
      this.datetimeStartWished,
      this.oobrPlaceInfo,
      this.invitedUsers,
      this.message,
      this.maxDateTimeAnswer});

  BrPlaceInviteModel.fromJson(Map<String, dynamic> json) {
    if (json["id"] is String) id = json["id"];
    if (json["datetimeStartWished"] is int)
      datetimeStartWished = json["datetimeStartWished"];
    if (json["maxDateTimeAnswer"] is int)
      maxDateTimeAnswer = json["maxDateTimeAnswer"];
    if (json["message"] is String) message = json["message"];
    if (json["oobrPlaceInfo"] is Map) {
      oobrPlaceInfo = json["oobrPlaceInfo"] == null
          ? null
          : OobrPlaceInfo.fromJson(json["oobrPlaceInfo"]);
    }
    if (json["invitedUsers"] is List) {
      invitedUsers = json["invitedUsers"] == null
          ? null
          : (json["invitedUsers"] as List)
              .map((e) => InvitedUsers.fromJson(e))
              .toList();
    }
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = <String, dynamic>{};
    data["id"] = id;
    data["datetimeStartWished"] = datetimeStartWished;
    data["maxDateTimeAnswer"] = maxDateTimeAnswer;
    data["message"] = message;
    if (oobrPlaceInfo != null) data["oobrPlaceInfo"] = oobrPlaceInfo?.toJson();
    if (invitedUsers != null) {
      data["invitedUsers"] = invitedUsers?.map((e) => e.toJson()).toList();
    }
    return data;
  }
}

class InvitedUsers {
  int? id;
  String? nickName;
  String? thumbnail;
  int? status;

  InvitedUsers({this.id, this.nickName, this.thumbnail, this.status});

  InvitedUsers.fromJson(Map<String, dynamic> json) {
    if (json["id"] is int) id = json["id"];
    if (json["status"] is int) status = json["status"];
    if (json["nickName"] is String) nickName = json["nickName"];
    if (json["thumbnail"] is String) thumbnail = json["thumbnail"];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = {};
    data["id"] = id;
    data["status"] = status;
    data["nickName"] = nickName;
    data["thumbnail"] = thumbnail;
    return data;
  }
}

class OobrPlaceInfo {
  String? id;
  String? name;
  String? description;
  String? pictureUrl;
  String? photoReference;
  String? subtitle;
  int? globalNote;
  int? lat;
  int? lng;
  String? street1;
  String? street2;
  String? zip;
  String? city;
  String? state;
  String? country;
  String? catName;
  String? colorCode;
  String? colorCode2;
  String? catThumbnail;
  int? favorite;

  OobrPlaceInfo(
      {this.id,
      this.name,
      this.description,
      this.pictureUrl,
      this.photoReference,
      this.subtitle,
      this.globalNote,
      this.lat,
      this.lng,
      this.street1,
      this.street2,
      this.zip,
      this.city,
      this.state,
      this.country,
      this.catName,
      this.colorCode,
      this.colorCode2,
      this.catThumbnail,
      this.favorite});

  OobrPlaceInfo.fromJson(Map<String, dynamic> json) {
    if (json["id"] is String) id = json["id"];
    if (json["name"] is String) name = json["name"];
    if (json["description"] is String) description = json["description"];
    if (json["pictureUrl"] is String) pictureUrl = json["pictureUrl"];
    if (json["photoReference"] is String)
      photoReference = json["photoReference"];
    if (json["subtitle"] is String) subtitle = json["subtitle"];
    if (json["globalNote"] is int) globalNote = json["globalNote"];
    if (json["lat"] is int) lat = json["lat"];
    if (json["lng"] is int) lng = json["lng"];
    if (json["street1"] is String) street1 = json["street1"];
    if (json["street2"] is String) street2 = json["street2"];
    if (json["zip"] is String) zip = json["zip"];
    if (json["city"] is String) city = json["city"];
    if (json["state"] is String) state = json["state"];
    if (json["country"] is String) country = json["country"];
    if (json["catName"] is String) catName = json["catName"];
    if (json["colorCode"] is String) colorCode = json["colorCode"];
    if (json["colorCode2"] is String) colorCode2 = json["colorCode2"];
    if (json["catThumbnail"] is String) catThumbnail = json["catThumbnail"];
    if (json["favorite"] is int) favorite = json["favorite"];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = new Map<String, dynamic>();
    data["id"] = id;
    data["name"] = name;
    data["description"] = description;
    data["pictureUrl"] = pictureUrl;
    data["photoReference"] = photoReference;
    data["subtitle"] = subtitle;
    data["globalNote"] = globalNote;
    data["lat"] = lat;
    data["lng"] = lng;
    data["street1"] = street1;
    data["street2"] = street2;
    data["zip"] = zip;
    data["city"] = city;
    data["state"] = state;
    data["country"] = country;
    data["catName"] = catName;
    data["colorCode"] = colorCode;
    data["colorCode2"] = colorCode2;
    data["catThumbnail"] = catThumbnail;
    data["favorite"] = favorite;
    return data;
  }
}

==> _private_core_network-0.0.75.tar.gz: lib/network_resources/model/br_place_invite.dart <==
import 'package:_private_core/_private_core.dart';

class BrPlaceInviteModel {
  String? id;
  int? datetimeStartWished;
  int? maxDateTimeAnswer;
  OobrPlaceInfo? oobrPlaceInfo;
  List<InvitedUsers>? invitedUsers;
  String? message;

  bool get isLate =>
      fromTimestamp(datetimeStartWished!).isBefore(DateTime.now()) ||
      fromTimestamp(maxDateTimeAnswer!).isBefore(DateTime.now());

  InvitedUsers get me =>
      invitedUsers!.firstWhere((e) => e.id == appPrefs.loginUser!.type);

  bool get wasAnwserd => me.status != null && me.status! > 0;

  BrPlaceInviteModel(
      {this.id,
      this.datetimeStartWished,
      this.oobrPlaceInfo,
      this.invitedUsers,
      this.message,
      this.maxDateTimeAnswer});

  BrPlaceInviteModel.fromJson(Map<String, dynamic> json) {
    if (json["id"] is String) id = json["id"];
    if (json["datetimeStartWished"] is int)
      datetimeStartWished = json["datetimeStartWished"];
    if (json["maxDateTimeAnswer"] is int)
      maxDateTimeAnswer = json["maxDateTimeAnswer"];
    if (json["message"] is String) message = json["message"];
    if (json["oobrPlaceInfo"] is Map) {
      oobrPlaceInfo = json["oobrPlaceInfo"] == null
          ? null
          : OobrPlaceInfo.fromJson(json["oobrPlaceInfo"]);
    }
    if (json["invitedUsers"] is List) {
      invitedUsers = json["invitedUsers"] == null
          ? null
          : (json["invitedUsers"] as List)
              .map((e) => InvitedUsers.fromJson(e))
              .toList();
    }
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = <String, dynamic>{};
    data["id"] = id;
    data["datetimeStartWished"] = datetimeStartWished;
    data["maxDateTimeAnswer"] = maxDateTimeAnswer;
    data["message"] = message;
    if (oobrPlaceInfo != null) data["oobrPlaceInfo"] = oobrPlaceInfo?.toJson();
    if (invitedUsers != null) {
      data["invitedUsers"] = invitedUsers?.map((e) => e.toJson()).toList();
    }
    return data;
  }
}

class InvitedUsers {
  int? id;
  String? displayName;
  String? thumbnail;
  int? status;

  InvitedUsers({this.id, this.displayName, this.thumbnail, this.status});

  InvitedUsers.fromJson(Map<String, dynamic> json) {
    if (json["id"] is int) id = json["id"];
    if (json["status"] is int) status = json["status"];
    if (json["displayName"] is String) displayName = json["displayName"];
    if (json["thumbnail"] is String) thumbnail = json["thumbnail"];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = {};
    data["id"] = id;
    data["status"] = status;
    data["displayName"] = displayName;
    data["thumbnail"] = thumbnail;
    return data;
  }
}

class OobrPlaceInfo {
  String? id;
  String? name;
  String? description;
  String? pictureUrl;
  String? photoReference;
  String? subtitle;
  int? globalNote;
  int? lat;
  int? lng;
  String? street1;
  String? street2;
  String? zip;
  String? city;
  String? state;
  String? country;
  String? catName;
  String? colorCode;
  String? colorCode2;
  String? catThumbnail;
  int? favorite;

  OobrPlaceInfo(
      {this.id,
      this.name,
      this.description,
      this.pictureUrl,
      this.photoReference,
      this.subtitle,
      this.globalNote,
      this.lat,
      this.lng,
      this.street1,
      this.street2,
      this.zip,
      this.city,
      this.state,
      this.country,
      this.catName,
      this.colorCode,
      this.colorCode2,
      this.catThumbnail,
      this.favorite});

  OobrPlaceInfo.fromJson(Map<String, dynamic> json) {
    if (json["id"] is String) id = json["id"];
    if (json["name"] is String) name = json["name"];
    if (json["description"] is String) description = json["description"];
    if (json["pictureUrl"] is String) pictureUrl = json["pictureUrl"];
    if (json["photoReference"] is String)
      photoReference = json["photoReference"];
    if (json["subtitle"] is String) subtitle = json["subtitle"];
    if (json["globalNote"] is int) globalNote = json["globalNote"];
    if (json["lat"] is int) lat = json["lat"];
    if (json["lng"] is int) lng = json["lng"];
    if (json["street1"] is String) street1 = json["street1"];
    if (json["street2"] is String) street2 = json["street2"];
    if (json["zip"] is String) zip = json["zip"];
    if (json["city"] is String) city = json["city"];
    if (json["state"] is String) state = json["state"];
    if (json["country"] is String) country = json["country"];
    if (json["catName"] is String) catName = json["catName"];
    if (json["colorCode"] is String) colorCode = json["colorCode"];
    if (json["colorCode2"] is String) colorCode2 = json["colorCode2"];
    if (json["catThumbnail"] is String) catThumbnail = json["catThumbnail"];
    if (json["favorite"] is int) favorite = json["favorite"];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = new Map<String, dynamic>();
    data["id"] = id;
    data["name"] = name;
    data["description"] = description;
    data["pictureUrl"] = pictureUrl;
    data["photoReference"] = photoReference;
    data["subtitle"] = subtitle;
    data["globalNote"] = globalNote;
    data["lat"] = lat;
    data["lng"] = lng;
    data["street1"] = street1;
    data["street2"] = street2;
    data["zip"] = zip;
    data["city"] = city;
    data["state"] = state;
    data["country"] = country;
    data["catName"] = catName;
    data["colorCode"] = colorCode;
    data["colorCode2"] = colorCode2;
    data["catThumbnail"] = catThumbnail;
    data["favorite"] = favorite;
    return data;
  }
}
